BlocFxPersistence class

Global persistence manager for BlocFx.

Initialize this at app startup to enable state persistence across all BlocFx and Cubitfx instances.

Constructors

BlocFxPersistence()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

isInitialized bool
no setter
storage BlocStorage
no setter

Static Methods

clearAll() Future<void>
initialize({BlocStorage? storage}) Future<void>
Initialize the global storage backend.