PersistedBlocFx<Event, State, Effect> class abstract

Base class for BlocFx with built-in state persistence.

This is a convenience class that combines BlocFx with automatic state persistence. Use this when you want persistence without having to use mixins.

Example usage:

class LoginBloc extends PersistedBlocFx<LoginEvent, LoginState, LoginEffect> {

  LoginBloc() : super(LoginState.initial());

  @override
  String get storageKey => 'login_bloc';

  @override
  LoginState fromJson(Map<String, dynamic> json) => LoginState.fromJson(json);

  @override
  Map<String, dynamic> toJson(LoginState state) => state.toJson();
}
Inheritance

Constructors

PersistedBlocFx(State initialState)

Properties

config PersistenceConfig
no setter
effects Stream<Effect>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
isClosed bool
Whether the bloc is closed.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state → State
The current state.
no setterinherited
storageKey String
no setter
stream Stream<State>
The current stream of states.
no setterinherited

Methods

add(Event event) → void
Notifies the Bloc of a new event which triggers all corresponding EventHandler instances.
inherited
addError(Object error, [StackTrace? stackTrace]) → void
Reports an error which triggers onError with an optional StackTrace.
inherited
clearPersistedState() Future<void>
Clear persisted state from storage.
close() Future<void>
Closes the event and state Streams. This method should be called when a Bloc is no longer needed. Once close is called, events that are added will not be processed. In addition, if close is called while events are still being processed, the Bloc will finish processing the pending events.
override
emit(State state) → void
emit is only for internal use and should never be called directly outside of tests. The Emitter instance provided to each EventHandler should be used instead.
inherited
emitEffect(Effect effect) → void
inherited
fromJson(Map<String, dynamic> json) → State
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
on<E extends Event>(EventHandler<E, State> handler, {EventTransformer<E>? transformer}) → void
Register event handler for an event of type E. There should only ever be one event handler per event type E.
inherited
onChange(Change<State> change) → void
Called whenever a change occurs with the given change. A change occurs when a new state is emitted. onChange is called before the state of the cubit is updated. onChange is a great spot to add logging/analytics for a specific cubit.
onDone(Event event, [Object? error, StackTrace? stackTrace]) → void
Called whenever an event handler for a specific Bloc has completed. This may include an error and stackTrace if an uncaught exception occurred within the event handler.
inherited
onError(Object error, StackTrace stackTrace) → void
Called whenever an error occurs and notifies BlocObserver.onError.
inherited
onEvent(Event event) → void
Called whenever an event is added to the Bloc. A great spot to add logging/analytics at the individual Bloc level.
inherited
onTransition(Transition<Event, State> transition) → void
Called whenever a transition occurs with the given transition. A transition occurs when a new event is added and a new state is emitted from a corresponding EventHandler.
inherited
persistState(State state) Future<void>
Persist current state to storage.
shouldPersist(State state) bool
toJson(State state) Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited